@@ -10,9 +10,6 @@
 
 // Qt
 #include <QIcon>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QNetworkConfigurationManager>
-#endif
 #include <QSet>
 #include <QUrl>
 #include <QVariant>
@@ -60,12 +57,6 @@ private:
     bool mEmptySuffix;
     QString mIdentifierError;
     QHash<QString, ComicProvider *> m_jobs;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QT_WARNING_PUSH
-    QT_WARNING_DISABLE_DEPRECATED
-    QNetworkConfigurationManager m_networkConfigurationManager;
-    QT_WARNING_POP
-#endif
     QSet<QString> mProviders;
 };
 
