@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 2014  David Edmundson <david@davidedmundson.co.uk>
+ * SPDX-FileCopyrightText: 2014 David Edmundson <david@davidedmundson.co.uk>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  */
 
@@ -21,19 +9,20 @@
 
 #include "note.h"
 
-#include <QUuid>
 #include <QDebug>
 #include <QStandardPaths>
+#include <QUuid>
 
 #include <KDirWatch>
 
 class FileNote : public Note
 {
-Q_OBJECT
+    Q_OBJECT
 public:
     FileNote(const QString &path, const QString &id);
     void load();
     void save(const QString &text) override;
+
 private:
     void fileSystemChanged(const QString &path);
     QString m_path;
@@ -48,10 +37,9 @@ FileSystemNoteLoader::FileSystemNoteLoader()
     m_notesDir.setPath(genericDataLocation + QDir::separator() + suffix);
 }
 
-
 QStringList FileSystemNoteLoader::allNoteIds()
 {
-    return m_notesDir.entryList(QStringList {QStringLiteral("*.txt")});
+    return m_notesDir.entryList(QStringList{QStringLiteral("*.txt")});
 }
 
 void FileSystemNoteLoader::deleteNoteResources(const QString &id)
@@ -59,21 +47,21 @@ void FileSystemNoteLoader::deleteNoteResources(const QString &id)
     m_notesDir.remove(id);
 }
 
-Note* FileSystemNoteLoader::loadNote(const QString &id)
+Note *FileSystemNoteLoader::loadNote(const QString &id)
 {
     QString idToUse = id;
     if (id.isEmpty()) {
-        idToUse = QUuid::createUuid().toString().mid(1, 34);//UUID adds random braces I don't want them on my file system
+        idToUse = QUuid::createUuid().toString().mid(1, 34); // UUID adds random braces I don't want them on my file system
     }
 
-    FileNote* note = new FileNote(m_notesDir.absoluteFilePath(idToUse), idToUse);
+    FileNote *note = new FileNote(m_notesDir.absoluteFilePath(idToUse), idToUse);
     return note;
 }
 
-FileNote::FileNote(const QString& path, const QString& id):
-    Note(id),
-    m_path(path),
-    m_watcher(new KDirWatch(this))
+FileNote::FileNote(const QString &path, const QString &id)
+    : Note(id)
+    , m_path(path)
+    , m_watcher(new KDirWatch(this))
 {
     m_watcher->addFile(path);
 
@@ -117,6 +105,4 @@ void FileNote::fileSystemChanged(const QString &path)
     }
 }
 
-
-
 #include "filesystemnoteloader.moc"
