@@ -12,26 +12,23 @@
 #include <KRunner/AbstractRunner>
 #include <KRunner/QueryMatch>
 #include <QDateTime>
+#include <QTimeZone>
 
-using namespace Plasma;
+using namespace KRunner;
 
 class DateTimeRunner : public AbstractRunner
 {
     Q_OBJECT
 
 public:
-    DateTimeRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    DateTimeRunner(QObject *parent, const KPluginMetaData &metaData);
     ~DateTimeRunner() override;
 
     void match(RunnerContext &context) override;
     void run(const RunnerContext &context, const QueryMatch &match) override;
 
 private:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QHash<QString, QDateTime> datetimeAt(const QStringRef &zoneTerm, const QDateTime referenceTime = QDateTime::currentDateTime());
-#else
-    QHash<QString, QDateTime> datetimeAt(const QStringView &zoneTerm, const QDateTime referenceTime = QDateTime::currentDateTime());
-#endif
+    QHash<QString, QTimeZone> matchingTimeZones(const QStringView &zoneTerm = QStringView(), const QDateTime referenceDatetime = QDateTime::currentDateTime());
     void addMatch(const QString &text, const QString &clipboardText, const qreal &relevance, const QString &iconName, RunnerContext &context);
 };
 
